#[repr(i32)]pub enum VmCursorEnum {
VmCursorUnspecified = 0,
VmCursorSrc = 1,
VmCursorDst = 2,
VmCursorBoth = 3,
}Variants
Implementations
Sourceimpl VmCursorEnum
impl VmCursorEnum
Sourceimpl VmCursorEnum
impl VmCursorEnum
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.