TracefsOption

Struct TracefsOption 

pub struct TracefsOption {
    pub name: Option<String>,
    pub state: Option<i32>,
}
Tracefs options to set directly in the tracefs instance. This is a very niche feature since almost all of the options deal with formatting textual output (the /trace file), which perfetto doesn’t use.

The options with a known use-case:

  • event-fork: when using tids_to_trace above, the kernel will automatically add newly spawned descendant threads to the set of TIDs.

Full list of options is available at https://docs.kernel.org/trace/ftrace.html#trace-options.

Note: this is an exclusive feature, see: https://perfetto.dev/docs/learning-more/android#exclusive-tracing-sessions.

Introduced in: perfetto v52. Supported on: Android 25Q3+.

Fields

name: Option<String>

The name of the tracefs option as found in tracefs/trace_options (without the “no” prefix).

state: Option<i32>

Implementations

Source

impl TracefsOption

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn state(&self) -> State

Returns the enum value of state, or the default if the field is unset or set to an invalid enum value.

pub fn set_state(&mut self, value: State)

Sets state to the provided enum value.