AtraceCategory

Struct AtraceCategory 

pub struct AtraceCategory {
    pub name: Option<String>,
    pub description: Option<String>,
}

Fields

name: Option<String>description: Option<String>

Implementations

Source

impl AtraceCategory

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.