pub struct Flush {
pub data_source_ids: Vec<u64>,
pub request_id: Option<u64>,
pub flags: Option<u64>,
}Fields
data_source_ids: Vec<u64>The instance id (i.e. StartDataSource.new_instance_id) of the data sources to flush.
request_id: Option<u64>A monotonic counter generated by the service. The producer is simply expected to copy this value back into the CommitDataRequest, so the service can tell when the data for this flush has been committed.
flags: Option<u64>More details such as flush reason and originator. Introduced in v38 / V. See FlushFlags in include/perfetto/ext/tracing/core/flush_flags.h.
Implementations