pub struct InstrumentedSamplingConfig {
pub activity_name_filters: Vec<ActivityNameFilter>,
pub activity_tx_include_globs: Vec<String>,
pub activity_tx_exclude_globs: Vec<String>,
pub activity_ranges: Vec<ActivityRange>,
}Expand description
Configuration for sampling counters by instrumenting command buffers.
When instrumented_sampling_config is used (instead of the instrumented_sampling bool), the following steps determine whether instrumented counters are enabled for a given GPU activity:
- Activity name filtering: If activity_name_filters is non-empty, the activity must match at least one filter. If empty, all activities pass this step.
- TX range filtering: If activity_tx_include_globs is non-empty, the activity must fall within a matching TX range. Activities in TX ranges matching activity_tx_exclude_globs are excluded (excludes take precedence over includes). If both are empty, all activities pass this step.
- Range-based sampling: If activity_ranges is non-empty, only activities within the specified skip/count ranges are instrumented. If empty, all activities that passed the previous steps are instrumented.
Fields
activity_name_filters: Vec<ActivityNameFilter>GPU activity name filters. An activity matches if it matches any filter.
activity_tx_include_globs: Vec<String>Glob patterns to use for including GPU activities in TX ranges. TX ranges are in-process annotations that mark different sections of GPU work (e.g. NVTX ranges for CUDA). TX ranges can be nested, and an activity is included if any range in its nesting hierarchy matches. Only activities that fall within a matching TX range will be instrumented.
activity_tx_exclude_globs: Vec<String>Glob patterns to use for excluding GPU activities from TX ranges. TX ranges can be nested, and an activity is excluded if any range in its nesting hierarchy matches. Excludes take precedence over includes.
activity_ranges: Vec<ActivityRange>Ranges of GPU activities to instrument. Applied after activity name and TX range filters. If empty, all activities that passed the previous filters are instrumented.