GpuCounterGroupSpec

Struct GpuCounterGroupSpec 

pub struct GpuCounterGroupSpec {
    pub group_id: Option<u32>,
    pub name: Option<String>,
    pub description: Option<String>,
    pub counter_ids: Vec<u32>,
}
Allow producer to define custom counter groups. Unlike the fixed GpuCounterGroup enum (which provides broad categories), these groups let the producer define hardware-specific groupings that the UI uses to organize counter tracks. Can also be used to provide display names and descriptions for the fixed GpuCounterGroup enum values by setting group_id to the enum value.

Fields

group_id: Option<u32>

required. Unique ID for this group within the descriptor.

name: Option<String>

optional. Display name for the group.

description: Option<String>

optional. Description of the group.

counter_ids: Vec<u32>

Counters that belong directly to this group (by counter_id).

Implementations

Source

impl GpuCounterGroupSpec

pub fn group_id(&self) -> u32

Returns the value of group_id, or the default value if group_id is unset.

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.