InvokeMethod

Struct InvokeMethod 

pub struct InvokeMethod {
    pub service_id: Option<u32>,
    pub method_id: Option<u32>,
    pub args_proto: Option<Vec<u8>>,
    pub drop_reply: Option<bool>,
}
Client -> Host.

Fields

service_id: Option<u32>

BindServiceReply.id.

method_id: Option<u32>

BindServiceReply.method.id.

args_proto: Option<Vec<u8>>

Proto-encoded request argument.

drop_reply: Option<bool>

When true the client specifies that a reply is not needed. The use case is a method with an empty, where the client doesn’t care about the success/failure of the method invocation and rather prefers avoiding the IPC roundtrip + context switch associated with the reply.

Implementations

Source

impl InvokeMethod

pub fn service_id(&self) -> u32

Returns the value of service_id, or the default value if service_id is unset.

pub fn method_id(&self) -> u32

Returns the value of method_id, or the default value if method_id is unset.

pub fn args_proto(&self) -> &[u8]

Returns the value of args_proto, or the default value if args_proto is unset.

pub fn drop_reply(&self) -> bool

Returns the value of drop_reply, or the default value if drop_reply is unset.