#[repr(i32)]pub enum Type {
Unspecified = 0,
DataSourcesInstances = 1,
AllDataSourcesStarted = 2,
CloneTriggerHit = 4,
}Variants
Unspecified = 0
DataSourcesInstances = 1
State changes of data source instances associated with the consumer’s session. Note that not all data sources may support these notifications. See |will_notify_on_start/stop| in DataSourceDescriptor.
AllDataSourcesStarted = 2
State change triggered when all data sources are in the STARTED state. For data sources that registered with |will_notify_on_start| this happens only after the data source has acked the start. This allows the consumer to synchronize with the data sources and to perform actions (e.g. start a test binary) only after trace recording is actually started. Introduced in Android 11 (R).
CloneTriggerHit = 4
When a tracing session has one or more triggers of type CLONE_SNAPSHOT and a matching trigger is hit, the service will send this notification to the consumer after |stop_delay_ms|.
Implementations
Sourceimpl Type
impl Type
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.