pub struct DataSourceInstanceStateChange {
pub producer_name: Option<String>,
pub data_source_name: Option<String>,
pub state: Option<i32>,
}Fields
producer_name: Option<String>data_source_name: Option<String>state: Option<i32>Implementations
Sourceimpl DataSourceInstanceStateChange
impl DataSourceInstanceStateChange
Sourcepub fn producer_name(&self) -> &str
pub fn producer_name(&self) -> &str
Returns the value of producer_name, or the default value if producer_name is unset.
Sourcepub fn data_source_name(&self) -> &str
pub fn data_source_name(&self) -> &str
Returns the value of data_source_name, or the default value if data_source_name is unset.
Sourcepub fn state(&self) -> DataSourceInstanceState
pub fn state(&self) -> DataSourceInstanceState
Returns the enum value of state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: DataSourceInstanceState)
pub fn set_state(&mut self, value: DataSourceInstanceState)
Sets state to the provided enum value.