RawEvent

Struct RawEvent 

pub struct RawEvent {
    pub type: Option<u32>,
    pub config: Option<u64>,
    pub config1: Option<u64>,
    pub config2: Option<u64>,
    pub pmu_name: Option<String>,
}
Syscall-level description of the event, propagated to the perf_event_attr struct. Primarily for local use-cases, since the event availability and encoding is hardware-specific.

Fields

type: Option<u32>

Either |type| or |pmu_name| can be set.

config: Option<u64>config1: Option<u64>config2: Option<u64>pmu_name: Option<String>

The name of a dynamic PMU under /sys/bus/event_source/devices (e.g. “armv8_pmuv3”). If set, leave |type| unset. Android: the relevant sysfs paths are not allowlisted by default, so this option will require a rooted device with selinux disabled.

Implementations

Source

impl RawEvent

pub fn type(&self) -> u32

Returns the value of type, or the default value if type is unset.

pub fn config(&self) -> u64

Returns the value of config, or the default value if config is unset.

pub fn config1(&self) -> u64

Returns the value of config1, or the default value if config1 is unset.

pub fn config2(&self) -> u64

Returns the value of config2, or the default value if config2 is unset.

pub fn pmu_name(&self) -> &str

Returns the value of pmu_name, or the default value if pmu_name is unset.