pub struct Scope {
pub target_cmdline: Vec<String>,
}Expand description
Which processes to record. At least one field must be set.
Fields
target_cmdline: Vec<String>Command line allowlist, matched against the /proc/
This field can specify a single wildcard (*), and the profiler will attempt to match it in two possible ways:
- if the pattern starts with a ‘/’, then it is matched against the first segment of the cmdline (i.e. argv0). For example “/bin/e*” would match “/bin/echo”.
- otherwise the pattern is matched against the part of argv0 corresponding to the binary name (this is unrelated to /proc/pid/exe). For example “echo” would match “/bin/echo”.
Implementation note: at most 511 characters of cmdline are considered.