#[repr(i32)]pub enum VmaField {
Show 13 variants
Unknown = 0,
Size = 1,
Rss = 2,
Anonymous = 3,
Swap = 4,
SharedClean = 5,
SharedDirty = 6,
PrivateClean = 7,
PrivateDirty = 8,
Locked = 9,
Pss = 10,
PssDirty = 11,
SwapPss = 12,
}Variants
Unknown = 0
Size = 1
Rss = 2
Anonymous = 3
Swap = 4
PrivateClean = 7
PrivateDirty = 8
Locked = 9
Pss = 10
PssDirty = 11
SwapPss = 12
Implementations
Sourceimpl VmaField
impl VmaField
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.