pub struct AndroidAflagsConfig {
pub poll_ms: Option<u32>,
}Expand description
Options for the android.aflags data source. This data source captures snapshots of Android aconfig flags. See https://source.android.com/docs/setup/build/feature-flagging/declare-flag for more information on aconfig flags.
Fields
poll_ms: Option<u32>Frequency of polling. If absent or 0, the state will be recorded once, at the start of the trace.
It is recommended to either leave this absent or set it to a large
value as each invocation of the aflags tool can be time consuming
(approx. 350ms) and also triggers an expensive flush. This is required to
be > 1000ms if set, to avoid excessive CPU usage.
Implementations