AndroidLogConfig

Struct AndroidLogConfig 

pub struct AndroidLogConfig {
    pub log_ids: Vec<i32>,
    pub min_prio: Option<i32>,
    pub filter_tags: Vec<String>,
    pub preserve_log_buffer: Option<bool>,
}

Fields

log_ids: Vec<i32>min_prio: Option<i32>

If set ignores all log messages whose prio is < the given value.

filter_tags: Vec<String>

If non-empty ignores all log messages whose tag doesn’t match one of the specified values.

preserve_log_buffer: Option<bool>

If true, includes the contents of the logcat buffers that were already present before the data source started. By default (false), only new log entries produced after the data source starts are recorded. Can be useful for boot traces or situations where logs from before traced started are important.

Implementations

Source

impl AndroidLogConfig

pub fn log_ids( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AndroidLogId>>

Returns an iterator which yields the valid enum values contained in log_ids.

pub fn push_log_ids(&mut self, value: AndroidLogId)

Appends the provided enum value to log_ids.

pub fn min_prio(&self) -> AndroidLogPriority

Returns the enum value of min_prio, or the default if the field is unset or set to an invalid enum value.

pub fn set_min_prio(&mut self, value: AndroidLogPriority)

Sets min_prio to the provided enum value.

pub fn preserve_log_buffer(&self) -> bool

Returns the value of preserve_log_buffer, or the default value if preserve_log_buffer is unset.