pub struct AndroidProcessStateConfig {
pub dump_process_metadata: Option<bool>,
}Expand description
Configuration for the “android.process_state” data source.
Fields
dump_process_metadata: Option<bool>If true, dumps process name, start seq id, and start time in the snapshot. When false (default), these fields are omitted to save trace buffer space.
Implementations
Sourceimpl AndroidProcessStateConfig
impl AndroidProcessStateConfig
Sourcepub fn dump_process_metadata(&self) -> bool
pub fn dump_process_metadata(&self) -> bool
Returns the value of dump_process_metadata, or the default value if dump_process_metadata is unset.