ChromeConfig

Struct ChromeConfig 

pub struct ChromeConfig {
    pub trace_config: Option<String>,
    pub privacy_filtering_enabled: Option<bool>,
    pub convert_to_legacy_json: Option<bool>,
    pub client_priority: Option<i32>,
    pub json_agent_label_filter: Option<String>,
    pub event_package_name_filter_enabled: Option<bool>,
}

Fields

trace_config: Option<String>privacy_filtering_enabled: Option<bool>

When enabled, the data source should only fill in fields in the output that are not potentially privacy sensitive.

convert_to_legacy_json: Option<bool>

Instead of emitting binary protobuf, convert the trace data to the legacy JSON format. Note that the trace data will still be returned as a series of TracePackets, but the embedded data will be JSON instead of serialized protobuf.

client_priority: Option<i32>json_agent_label_filter: Option<String>

Applicable only when using legacy JSON format. If |json_agent_label_filter| is not empty, only data pertaining to the specified tracing agent label (e.g. “traceEvents”) will be returned.

event_package_name_filter_enabled: Option<bool>

When enabled, event names should not contain package names.

Implementations

Source

impl ChromeConfig

pub fn trace_config(&self) -> &str

Returns the value of trace_config, or the default value if trace_config is unset.

pub fn privacy_filtering_enabled(&self) -> bool

Returns the value of privacy_filtering_enabled, or the default value if privacy_filtering_enabled is unset.

pub fn convert_to_legacy_json(&self) -> bool

Returns the value of convert_to_legacy_json, or the default value if convert_to_legacy_json is unset.

pub fn client_priority(&self) -> ClientPriority

Returns the enum value of client_priority, or the default if the field is unset or set to an invalid enum value.

pub fn set_client_priority(&mut self, value: ClientPriority)

Sets client_priority to the provided enum value.

pub fn json_agent_label_filter(&self) -> &str

Returns the value of json_agent_label_filter, or the default value if json_agent_label_filter is unset.

pub fn event_package_name_filter_enabled(&self) -> bool

Returns the value of event_package_name_filter_enabled, or the default value if event_package_name_filter_enabled is unset.