CloneSessionResponse

Struct CloneSessionResponse 

pub struct CloneSessionResponse {
    pub success: Option<bool>,
    pub error: Option<String>,
    pub uuid_msb: Option<i64>,
    pub uuid_lsb: Option<i64>,
    pub was_write_into_file: Option<bool>,
}

Fields

success: Option<bool>

If true, the clone was successful. If false it failed and |error| contains the details about the failure.

error: Option<String>uuid_msb: Option<i64>

The UUID of the cloned session.

uuid_lsb: Option<i64>was_write_into_file: Option<bool>

TracingService sets this when the cloned session was write_into_file=true. The consumer cannot know upfront if a session is WIF or not. Introduced in v53.

Implementations

Source

impl CloneSessionResponse

pub fn success(&self) -> bool

Returns the value of success, or the default value if success is unset.

pub fn error(&self) -> &str

Returns the value of error, or the default value if error is unset.

pub fn uuid_msb(&self) -> i64

Returns the value of uuid_msb, or the default value if uuid_msb is unset.

pub fn uuid_lsb(&self) -> i64

Returns the value of uuid_lsb, or the default value if uuid_lsb is unset.

pub fn was_write_into_file(&self) -> bool

Returns the value of was_write_into_file, or the default value if was_write_into_file is unset.