pub struct ConsoleConfig {
pub output: Option<i32>,
pub enable_colors: Option<bool>,
}Fields
output: Option<i32>enable_colors: Option<bool>Implementations
Sourceimpl ConsoleConfig
impl ConsoleConfig
Sourcepub fn output(&self) -> Output
pub fn output(&self) -> Output
Returns the enum value of output, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_output(&mut self, value: Output)
pub fn set_output(&mut self, value: Output)
Sets output to the provided enum value.
Sourcepub fn enable_colors(&self) -> bool
pub fn enable_colors(&self) -> bool
Returns the value of enable_colors, or the default value if enable_colors is unset.