pub struct ProcessSmapsConfig {
pub smaps_config: Option<SmapsConfig>,
pub scope: Option<Scope>,
pub read_period_ms: Option<u32>,
}Expand description
Config for the “linux.smaps” data source, describes one-shot or periodic /proc/pid/smaps collection.
A valid config must specify at least one |target_cmdline|. Example:
data_sources { config { name: “linux.smaps” process_smaps_config { scope { target_cmdline: “top” target_cmdline: “tmux” } } } }
Fields
smaps_config: Option<SmapsConfig>Which fields to record per process. If unset, defaults to {size, rss, anon, swap}, aggregated by path name.
scope: Option<Scope>read_period_ms: Option<u32>How often to recapture the smaps, including re-evaluating which processes match the |scope|. May be overridden by the implementation (at the time of writing, [1s, 24hr] range). If zero or unset, each process is captured only once at start.
Implementations
Sourceimpl ProcessSmapsConfig
impl ProcessSmapsConfig
Sourcepub fn read_period_ms(&self) -> u32
pub fn read_period_ms(&self) -> u32
Returns the value of read_period_ms, or the default value if read_period_ms is unset.