pub struct SaveTraceForBugreportResponse {
pub success: Option<bool>,
pub msg: Option<String>,
}Expand description
This response is sent only after the trace was saved into file (if succeeded) or something failed.
Fields
success: Option<bool>If true, an eligible the trace was saved into a known location (on Android /data/misc/perfetto-traces, see GetBugreportTracePath()). If false no trace with bugreport_score > 0 was found or an error occurred. see |msg| in that case for details about the failure.
msg: Option<String>Implementations