SystemInfoConfig

Struct SystemInfoConfig 

pub struct SystemInfoConfig {
    pub irq_names: Option<bool>,
}
This data-source does a one-off recording of system information when the trace starts. Currently this includes:

  • Values of /sys/devices/system/cpu/cpu*/cpufreq/scaling_available_frequencies This datasource has no configuration options at present.

Fields

irq_names: Option<bool>

If true, records hardware interrupt ID-to-name mappings from /proc/interrupts.

Implementations

Source

impl SystemInfoConfig

pub fn irq_names(&self) -> bool

Returns the value of irq_names, or the default value if irq_names is unset.