TraceAttributes

Struct TraceAttributes 

pub struct TraceAttributes {
    pub attribute: Vec<Attribute>,
}
Arbitrary key value pairs which can attached to a trace to provide context about any facet of the trace. This can include, what data it contains, properties of the host / machine the trace was collected on, and other interesting information about a trace. / Examples include: gradle_version = “9.0.10-alpha01” java_major_version = 24 / Attributes can be written as a TracePacket or set in TraceConfig.trace_attributes (e.g. via perfetto --add-attribute). / All keys get prefixed with trace_attribute. in the UI and in traceprocessor. If there are multiple trace attribute packets that use the same key, then the latest value wins. These key value pairs show up in the Overview section in Perfetto UI. Additionally, these key, value pairs can also be queried using Pefetto SQL by using the following query: / SELECT * FROM metadata WHERE name GLOB 'trace_attribute.*';

Fields

attribute: Vec<Attribute>