VmOpMerge

Struct VmOpMerge 

pub struct VmOpMerge {
    pub skip_submessages: Option<bool>,
    pub del_if_src_empty: Option<bool>,
}
Merges SRC into DST. Both need to point to a message (not a field).

Fields

skip_submessages: Option<bool>

When true, the merge operation will skip any field that is already resolved as a message node in the destination tree.

This is used to support merging of nested messages. Because ProtoVM does not know the schema, a standard MERGE cannot distinguish between a string and a message on the wire and it would overwrite the entire blob, destroying granular updates.

By setting this to true, a program can be implemented to do a bottom-up, multi-step merge by traversing into and merging the deepest submessages first, then moving up to the parent message and merging it with skip_submessages = true.

del_if_src_empty: Option<bool>

When true, the merge operation will remove the dst field if the src field is empty.

This can be used to replicate the removal of a subobject within the producer’s state. E.g. This event on the producer side: mProducerState.mSubobject = nullptr can be represented by this patch: { producer_state { subobject {} }}

Implementations

Source

impl VmOpMerge

pub fn skip_submessages(&self) -> bool

Returns the value of skip_submessages, or the default value if skip_submessages is unset.

pub fn del_if_src_empty(&self) -> bool

Returns the value of del_if_src_empty, or the default value if del_if_src_empty is unset.