pub struct VmOpRegLoad {
pub cursor: Option<i32>,
pub dst_register: Option<u32>,
}Fields
cursor: Option<i32>SRC(default) | DST.
dst_register: Option<u32>1=R1, 2=R2… 32=R32
Implementations
Sourceimpl VmOpRegLoad
impl VmOpRegLoad
Sourcepub fn cursor(&self) -> VmCursorEnum
pub fn cursor(&self) -> VmCursorEnum
Returns the enum value of cursor, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_cursor(&mut self, value: VmCursorEnum)
pub fn set_cursor(&mut self, value: VmCursorEnum)
Sets cursor to the provided enum value.
Sourcepub fn dst_register(&self) -> u32
pub fn dst_register(&self) -> u32
Returns the value of dst_register, or the default value if dst_register is unset.