pub struct VmOpSelect {
pub cursor: Option<i32>,
pub relative_path: Vec<PathComponent>,
pub create_if_not_exist: Option<bool>,
}Fields
cursor: Option<i32>Enum SRC|DST|BOTH. Default=SRC.
relative_path: Vec<PathComponent>create_if_not_exist: Option<bool>Creates the submessage if doesn’t exist in the DST cursor (think of mkdir -p). Only valid when cursor=DST|BOTH.
Implementations
Sourceimpl VmOpSelect
impl VmOpSelect
Sourcepub fn cursor(&self) -> VmCursorEnum
pub fn cursor(&self) -> VmCursorEnum
Returns the enum value of cursor, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_cursor(&mut self, value: VmCursorEnum)
pub fn set_cursor(&mut self, value: VmCursorEnum)
Sets cursor to the provided enum value.
Sourcepub fn create_if_not_exist(&self) -> bool
pub fn create_if_not_exist(&self) -> bool
Returns the value of create_if_not_exist, or the default value if create_if_not_exist is unset.