#[repr(i32)]pub enum ExperimentalMode {
ModeUnspecified = 0,
TraceBufferV2 = 1,
}Expand description
When true, uses the experimental TraceBufferV2 implementation for this buffer. This is for testing purposes only and may be removed in future versions.
Variants
Implementations
Sourceimpl ExperimentalMode
impl ExperimentalMode
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ExperimentalMode.
Sourcepub fn from_i32(value: i32) -> Option<ExperimentalMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ExperimentalMode>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ExperimentalMode, or None if value is not a valid variant.
Sourceimpl ExperimentalMode
impl ExperimentalMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.