#[repr(i32)]pub enum WriteFlushMode {
WriteFlushUnspecified = 0,
WriteFlushAuto = 1,
WriteFlushDisabled = 2,
WriteFlushEnabled = 3,
}Variants
WriteFlushUnspecified = 0
Same as WRITE_FLUSH_AUTO.
WriteFlushAuto = 1
Default mode. The service automatically determines the flush frequency to balance performance and data freshness:
- If file_write_period_ms <= 5s (kDefaultWriteIntoFilePeriodMs): Flushes are NOT issued on every write. Instead, a periodic flush is issued every 5s.
- If file_write_period_ms > 5s: A flush is issued before every periodic write into the file.
WriteFlushDisabled = 2
Do not flush buffers before periodic writes into the file. Use this mode if you want to minimize the performance impact of flushes and can tolerate potentially missing the most recent data in the trace file until the end of the session or an explicit flush. When this mode is selected, |flush_period_ms| is respected.
WriteFlushEnabled = 3
Issue a flush before every periodic write into the file. This ensures that each write into the file contains the most up-to-date data from all data sources, but may have a higher performance overhead.
Implementations
Sourceimpl WriteFlushMode
impl WriteFlushMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.