pub struct CompressionConfig {
pub deflate: Option<Deflate>,
pub zstd: Option<Zstd>,
}Expand description
Selects and configures the compression codec, superseding |compression_type|. The codec is chosen by which sub-message is set; when several are set the service picks the highest-numbered one it supports and ignores codecs it doesn’t know, so a single config can target old and new services. Falls back to |compression_type| (deflate-only), if given.
Introduced in: perfetto v58. Supported on: Android 26Q3+.
Fields
deflate: Option<Deflate>If a config sets more than one of these, the service picks the one with the highest field number (see the rule above): e.g. with deflate (1) and zstd (2) both set, zstd wins.
zstd: Option<Zstd>Trait Implementations
Sourceimpl Clone for CompressionConfig
impl Clone for CompressionConfig
Sourcefn clone(&self) -> CompressionConfig
fn clone(&self) -> CompressionConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CompressionConfig
Sourceimpl Debug for CompressionConfig
impl Debug for CompressionConfig
Sourceimpl Default for CompressionConfig
impl Default for CompressionConfig
impl Eq for CompressionConfig
Sourceimpl Hash for CompressionConfig
impl Hash for CompressionConfig
Sourceimpl Message for CompressionConfig
impl Message for CompressionConfig
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CompressionConfig
impl PartialEq for CompressionConfig
Sourcefn eq(&self, other: &CompressionConfig) -> bool
fn eq(&self, other: &CompressionConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompressionConfig