pub struct Producer {
pub id: Option<i32>,
pub name: Option<String>,
pub pid: Option<i32>,
pub uid: Option<i32>,
pub sdk_version: Option<String>,
pub frozen: Option<bool>,
pub machine_id: Option<u32>,
pub machine_name: Option<String>,
}Expand description
Describes a producer process.
Fields
id: Option<i32>Unique ID of the producer (monotonic counter).
name: Option<String>Typically matches the process name.
pid: Option<i32>Unix pid of the remote process. Supported only on Linux-based systems. Introduced in v24 / Android T.
uid: Option<i32>Unix uid of the remote process.
sdk_version: Option<String>The version of the client library used by the producer. This is a human readable string with and its format varies depending on the build system and the repo (standalone vs AOSP). This is intended for human debugging only.
frozen: Option<bool>Returns true if the process appears to be frozen (Android only). Introduced in Perfetto V49 / Android 24Q4.
machine_id: Option<u32>Identifies the machine this producer is connected from in multi-machine tracing setups (e.g. when going through traced_relay). Unset (or zero) means the producer is connected from the local/host machine where the tracing service is running. Introduced in Perfetto V56 / Android 26Q3.
machine_name: Option<String>Human-readable name of the machine, as advertised by the relay (usually
the value of PERFETTO_MACHINE_NAME on the remote, falling back to the
remote’s uname -s). Only set when machine_id is non-zero.
Introduced in Perfetto V56 / Android 26Q3.
Implementations
Sourceimpl Producer
impl Producer
Sourcepub fn sdk_version(&self) -> &str
pub fn sdk_version(&self) -> &str
Returns the value of sdk_version, or the default value if sdk_version is unset.
Sourcepub fn frozen(&self) -> bool
pub fn frozen(&self) -> bool
Returns the value of frozen, or the default value if frozen is unset.
Sourcepub fn machine_id(&self) -> u32
pub fn machine_id(&self) -> u32
Returns the value of machine_id, or the default value if machine_id is unset.
Sourcepub fn machine_name(&self) -> &str
pub fn machine_name(&self) -> &str
Returns the value of machine_name, or the default value if machine_name is unset.