#[repr(i32)]pub enum AbortLevel {
SkipCurrentInstruction = 1,
SkipCurrentInstructionAndBreakOuter = 2,
Abort = 3,
}Variants
SkipCurrentInstruction = 1
Skip current instruction but execute following ones
SkipCurrentInstructionAndBreakOuter = 2
Skip current instruction as well as following ones (default)
Abort = 3
Abort whole program
Implementations
Sourceimpl AbortLevel
impl AbortLevel
Sourceimpl AbortLevel
impl AbortLevel
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.