pub enum Field {
FieldId(u32),
ArrayIndex(u32),
MapKeyFieldId(u32),
}Variants
FieldId(u32)
ArrayIndex(u32)
MapKeyFieldId(u32)
The ID of the field in the repeated submessage that we use as a key (e.g. LayerState.layer_id). When setting this register_to_match must also be set, to tell what’s the expected value of the key we are looking up.
Implementations
Sourceimpl Field
impl Field
Sourcepub fn merge<B>(
field: &mut Option<Field>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Field>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.