PathComponent

Struct PathComponent 

pub struct PathComponent {
    pub is_repeated: Option<bool>,
    pub register_to_match: Option<u32>,
    pub store_foreach_index_into_register: Option<u32>,
    pub field: Option<Field>,
}
A path component is either: (1) a field id to descend into (common case); (2) an array index (for repeated fields); (3) a map lookup operation (for repeated fields, where we snoop a sub-field as a map key)

Fields

is_repeated: Option<bool>

Only valid when using field_id. This makes select have foreach semantics. This means that the body of nested_instructions is executed several times, once per each repeated submessage.

register_to_match: Option<u32>

Only valid when using map_key_field_id. This defines which register (R1..R32) should be used to match the key of the dict in a map lookup operation. In other words: foreach msg in repeated message { if msg[map_key_field_id] == R[register_to_match] { break; // Lookup succeeded, PathComponent resolves here. } }

store_foreach_index_into_register: Option<u32>

Only valid when using field_id and is_repeated=true. When iterating over repeated fields, stores the current iteration index into the the register R1..R32 defined below. This can be used to do complex operations like “find the entry in the array that has width==100, remember its offset in the SRC array and overwrite the matching i-th element in the DST array. We will probably never implement this but it’s here for completeness.

field: Option<Field>

Implementations

Source

impl PathComponent

pub fn is_repeated(&self) -> bool

Returns the value of is_repeated, or the default value if is_repeated is unset.

pub fn register_to_match(&self) -> u32

Returns the value of register_to_match, or the default value if register_to_match is unset.

pub fn store_foreach_index_into_register(&self) -> u32

Returns the value of store_foreach_index_into_register, or the default value if store_foreach_index_into_register is unset.