#[repr(i32)]pub enum LogMode {
Unspecified = 0,
FullState = 1,
Incremental = 2,
}Variants
Unspecified = 0
FullState = 1
Always logs a full state dump of the window hierarchy.
Incremental = 2
Logs a full state dump of the window hierarchy only when tracing starts. The following trace packets are lightweight patches containing only the last changes.
Implementations
Sourceimpl LogMode
impl LogMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.