#[repr(i32)]pub enum BufferExhaustedPolicy {
BufferExhaustedUnspecified = 0,
BufferExhaustedDrop = 1,
BufferExhaustedStallThenAbort = 2,
BufferExhaustedStallThenDrop = 3,
}Variants
BufferExhaustedUnspecified = 0
The data source will use its default buffer exhausted policy, specified by the code when the data source is registered.
BufferExhaustedDrop = 1
The data source will drop packets when there’s no space in the shared memory buffer.
BufferExhaustedStallThenAbort = 2
The data source will wait when there’s no space in the shared memory buffer. If there’s still not space, after a few seconds, the whole producer process will be aborted.
BufferExhaustedStallThenDrop = 3
The data source will wait when there’s no space in the shared memory buffer. If there’s still not space, after a few seconds, the data source will drop packets.
Implementations
Sourceimpl BufferExhaustedPolicy
impl BufferExhaustedPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.