pub struct ActivityRange {
pub skip: Option<u32>,
pub count: Option<u32>,
}Expand description
Defines a range of GPU activities to instrument.
Fields
skip: Option<u32>Number of GPU activities to skip before starting to instrument command buffers. Defaults to 0 if not specified.
count: Option<u32>Limit for the number of GPU activities to sample counters for by instrumenting command buffers. Defaults to UINT32_MAX (all remaining activities) if not specified.
Implementations