pub struct RawEvent {
pub type: Option<u32>,
pub config: Option<u64>,
pub config1: Option<u64>,
pub config2: Option<u64>,
pub pmu_name: Option<String>,
}Expand description
Syscall-level description of the event, propagated to the perf_event_attr struct. Primarily for local use-cases, since the event availability and encoding is hardware-specific.
Fields
type: Option<u32>Either |type| or |pmu_name| can be set.
config: Option<u64>config1: Option<u64>config2: Option<u64>pmu_name: Option<String>The name of a dynamic PMU under /sys/bus/event_source/devices (e.g. “armv8_pmuv3”). If set, leave |type| unset. Android: the relevant sysfs paths are not allowlisted by default, so this option will require a rooted device with selinux disabled.
Implementations
Sourceimpl RawEvent
impl RawEvent
Sourcepub fn config(&self) -> u64
pub fn config(&self) -> u64
Returns the value of config, or the default value if config is unset.
Sourcepub fn config1(&self) -> u64
pub fn config1(&self) -> u64
Returns the value of config1, or the default value if config1 is unset.