pub struct CloneSessionRequest {
pub skip_trace_filter: Option<bool>,
pub for_bugreport: Option<bool>,
pub clone_trigger_name: Option<String>,
pub clone_trigger_producer_name: Option<String>,
pub clone_trigger_trusted_producer_uid: Option<i32>,
pub clone_trigger_boot_time_ns: Option<u64>,
pub clone_trigger_delay_ms: Option<u64>,
pub selector: Option<Selector>,
}Expand description
Arguments for rpc CloneSession.
Fields
skip_trace_filter: Option<bool>If set, the trace filter will not have effect on the cloned session. Used for bugreports.
for_bugreport: Option<bool>If set, affects the generation of the FlushFlags::CloneTarget to be set to kBugreport when requesting the flush to the producers.
clone_trigger_name: Option<String>If set, this is stored in the trace as name of the trigger that caused the clone.
clone_trigger_producer_name: Option<String>If set, this is stored in the trace as name of the producer that triggered the clone.
clone_trigger_trusted_producer_uid: Option<i32>If set, this is stored in the trace as uid of the producer that triggered the clone.
clone_trigger_boot_time_ns: Option<u64>If set, this is stored in the trace as timestamp of the trigger that caused the clone.
clone_trigger_delay_ms: Option<u64>If set, this is stored in the trace as the configured delay of the trigger that caused the clone.
Consumer may also send a file descriptor with this rpc message. If the descriptor is valid, and the session that should be cloned is ‘write_into_file’ session, traced writes the cloned session content to that file descriptor, instead of writing it in the cloned session buffers.
selector: Option<Selector>Implementations
Sourceimpl CloneSessionRequest
impl CloneSessionRequest
Sourcepub fn skip_trace_filter(&self) -> bool
pub fn skip_trace_filter(&self) -> bool
Returns the value of skip_trace_filter, or the default value if skip_trace_filter is unset.
Sourcepub fn for_bugreport(&self) -> bool
pub fn for_bugreport(&self) -> bool
Returns the value of for_bugreport, or the default value if for_bugreport is unset.
Sourcepub fn clone_trigger_name(&self) -> &str
pub fn clone_trigger_name(&self) -> &str
Returns the value of clone_trigger_name, or the default value if clone_trigger_name is unset.
Sourcepub fn clone_trigger_producer_name(&self) -> &str
pub fn clone_trigger_producer_name(&self) -> &str
Returns the value of clone_trigger_producer_name, or the default value if clone_trigger_producer_name is unset.
Sourcepub fn clone_trigger_trusted_producer_uid(&self) -> i32
pub fn clone_trigger_trusted_producer_uid(&self) -> i32
Returns the value of clone_trigger_trusted_producer_uid, or the default value if clone_trigger_trusted_producer_uid is unset.
Sourcepub fn clone_trigger_boot_time_ns(&self) -> u64
pub fn clone_trigger_boot_time_ns(&self) -> u64
Returns the value of clone_trigger_boot_time_ns, or the default value if clone_trigger_boot_time_ns is unset.
Sourcepub fn clone_trigger_delay_ms(&self) -> u64
pub fn clone_trigger_delay_ms(&self) -> u64
Returns the value of clone_trigger_delay_ms, or the default value if clone_trigger_delay_ms is unset.