GpuRenderStagesConfig

Struct GpuRenderStagesConfig 

pub struct GpuRenderStagesConfig {
    pub full_loadstore: Option<bool>,
    pub low_overhead: Option<bool>,
    pub trace_metrics: Vec<String>,
}

Fields

full_loadstore: Option<bool>

Enable to separate the color and depth/stencil load and store stages into a separate stages. If disabled, the depth/stencil load and store stages will be combined. Disabled by default. This option has no effect if Low Overhead mode is enabled.

low_overhead: Option<bool>

Use the low overhead mode for traces. In this mode render stages are combined into a single workload stage. This provides less granular data but induces minimal GPU overhead. Disabled by default.

trace_metrics: Vec<String>

Trace metrics to capture for each render stage

Implementations

Source

impl GpuRenderStagesConfig

pub fn full_loadstore(&self) -> bool

Returns the value of full_loadstore, or the default value if full_loadstore is unset.

pub fn low_overhead(&self) -> bool

Returns the value of low_overhead, or the default value if low_overhead is unset.