pub struct QnxConfig {
pub qnx_kernel_buffers: Option<u32>,
pub qnx_kernel_kbuffers: Option<u32>,
pub qnx_kernel_wide_events: Option<bool>,
pub qnx_cache_pages: Option<u32>,
pub qnx_cache_max_pages: Option<i32>,
pub qnx_trace_buffer_init_bytes: Option<u32>,
}Expand description
QnxConfig is used with trace_qnx_probes build from https://github.com/qnx-ports/perfetto
Fields
qnx_kernel_buffers: Option<u32>The number of buffers that tracelog will init for the QNX trace.
qnx_kernel_kbuffers: Option<u32>The number of kernel buffers that tracelog will init for the QNX trace.
qnx_kernel_wide_events: Option<bool>Flag indicating whether the QNX kernel tracing should produce wide events which contain additional data or fast events which are most concise. In fast mode we lose the priority information
qnx_cache_pages: Option<u32>The number of pages initialized by default the parser’s page cache.
qnx_cache_max_pages: Option<i32>The max pages the page cache should allocate (must be at least as big) as the qnx_cache_pages value. Using -1 will allow the cache to grow unbounded. The cache will prefer to re-use existing pages so growth will only happen when needed (when parser is not keeping up).
qnx_trace_buffer_init_bytes: Option<u32>The initial size of the the buffer used to hold the trace header values this dynamic buffer will grow as needed but reallocs can be avoided by selecting an initial size large enough to hold all the initial header data.
Implementations
Sourceimpl QnxConfig
impl QnxConfig
Sourcepub fn qnx_kernel_buffers(&self) -> u32
pub fn qnx_kernel_buffers(&self) -> u32
Returns the value of qnx_kernel_buffers, or the default value if qnx_kernel_buffers is unset.
Sourcepub fn qnx_kernel_kbuffers(&self) -> u32
pub fn qnx_kernel_kbuffers(&self) -> u32
Returns the value of qnx_kernel_kbuffers, or the default value if qnx_kernel_kbuffers is unset.
Sourcepub fn qnx_kernel_wide_events(&self) -> bool
pub fn qnx_kernel_wide_events(&self) -> bool
Returns the value of qnx_kernel_wide_events, or the default value if qnx_kernel_wide_events is unset.
Sourcepub fn qnx_cache_pages(&self) -> u32
pub fn qnx_cache_pages(&self) -> u32
Returns the value of qnx_cache_pages, or the default value if qnx_cache_pages is unset.
Sourcepub fn qnx_cache_max_pages(&self) -> i32
pub fn qnx_cache_max_pages(&self) -> i32
Returns the value of qnx_cache_max_pages, or the default value if qnx_cache_max_pages is unset.
Sourcepub fn qnx_trace_buffer_init_bytes(&self) -> u32
pub fn qnx_trace_buffer_init_bytes(&self) -> u32
Returns the value of qnx_trace_buffer_init_bytes, or the default value if qnx_trace_buffer_init_bytes is unset.