pub struct TraceAttributes {
pub attribute: Vec<Attribute>,
}Expand description
Arbitrary key value pairs which can attached to a trace to provide context
about any facet of the trace. This can include, what data it contains,
properties of the host / machine the trace was collected on, and other
interesting information about a trace.
/
Examples include:
gradle_version = “9.0.10-alpha01”
java_major_version = 24
/
Attributes can be written as a TracePacket or set in
TraceConfig.trace_attributes (e.g. via perfetto --add-attribute).
/
All keys get prefixed with trace_attribute. in the UI and in
traceprocessor. If there are multiple trace attribute packets that use the
same key, then the latest value wins.
These key value pairs show up in the Overview section in
Perfetto UI. Additionally, these key, value pairs can also be queried using
Pefetto SQL by using the following query:
/
SELECT * FROM metadata WHERE name GLOB 'trace_attribute.*';
Fields
attribute: Vec<Attribute>Trait Implementations
Sourceimpl Clone for TraceAttributes
impl Clone for TraceAttributes
Sourcefn clone(&self) -> TraceAttributes
fn clone(&self) -> TraceAttributes
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TraceAttributes
impl Debug for TraceAttributes
Sourceimpl Default for TraceAttributes
impl Default for TraceAttributes
Sourceimpl Message for TraceAttributes
impl Message for TraceAttributes
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.