pub struct ShadowBufferStats {
pub packets_seen: Option<u64>,
pub packets_in_both: Option<u64>,
pub packets_only_v1: Option<u64>,
pub packets_only_v2: Option<u64>,
pub patches_attempted: Option<u64>,
pub v1_patches_succeeded: Option<u64>,
pub v2_patches_succeeded: Option<u64>,
pub stats_version: Option<u32>,
}Expand description
Statistics for TRACE_BUFFER_V2_SHADOW_MODE comparison. Only populated when the buffer is configured with shadow mode.
Fields
packets_seen: Option<u64>Total num. packets read. This is not affected by capping of the hasher to 32K elements.
packets_in_both: Option<u64>Num. packets found in both V1 and V2 buffers (matched by content hash).
packets_only_v1: Option<u64>Num. packets found only in V1 buffer but not in V2.
packets_only_v2: Option<u64>Num. packets found only in V2 buffer but not in V1.
patches_attempted: Option<u64>Num. patch operations attempted.
v1_patches_succeeded: Option<u64>Num. patches that succeeded on V1 buffer.
v2_patches_succeeded: Option<u64>Num. patches that succeeded on V2 buffer.
stats_version: Option<u32>This is to distinguish the updated calculations after fixing the hashes. This field is either empty or “2”
Implementations
Sourceimpl ShadowBufferStats
impl ShadowBufferStats
Sourcepub fn packets_seen(&self) -> u64
pub fn packets_seen(&self) -> u64
Returns the value of packets_seen, or the default value if packets_seen is unset.
Sourcepub fn packets_in_both(&self) -> u64
pub fn packets_in_both(&self) -> u64
Returns the value of packets_in_both, or the default value if packets_in_both is unset.
Sourcepub fn packets_only_v1(&self) -> u64
pub fn packets_only_v1(&self) -> u64
Returns the value of packets_only_v1, or the default value if packets_only_v1 is unset.
Sourcepub fn packets_only_v2(&self) -> u64
pub fn packets_only_v2(&self) -> u64
Returns the value of packets_only_v2, or the default value if packets_only_v2 is unset.
Sourcepub fn patches_attempted(&self) -> u64
pub fn patches_attempted(&self) -> u64
Returns the value of patches_attempted, or the default value if patches_attempted is unset.
Sourcepub fn v1_patches_succeeded(&self) -> u64
pub fn v1_patches_succeeded(&self) -> u64
Returns the value of v1_patches_succeeded, or the default value if v1_patches_succeeded is unset.
Sourcepub fn v2_patches_succeeded(&self) -> u64
pub fn v2_patches_succeeded(&self) -> u64
Returns the value of v2_patches_succeeded, or the default value if v2_patches_succeeded is unset.
Sourcepub fn stats_version(&self) -> u32
pub fn stats_version(&self) -> u32
Returns the value of stats_version, or the default value if stats_version is unset.